@@ -85,7 +85,7 @@ struct GnomeVFSSSL {
 };
 
 void 
-_gnome_vfs_ssl_init () {
+_gnome_vfs_ssl_init (void) {
 #ifdef HAVE_OPENSSL
 	SSL_library_init ();
 #elif defined HAVE_GNUTLS
@@ -103,7 +103,7 @@ _gnome_vfs_ssl_init () {
  * otherwise %FALSE.
  **/
 gboolean
-gnome_vfs_ssl_enabled ()
+gnome_vfs_ssl_enabled (void)
 {
 #if defined HAVE_OPENSSL || defined HAVE_GNUTLS
 	return TRUE;
@@ -413,7 +413,7 @@ gnome_vfs_ssl_read (GnomeVFSSSL *ssl,
 		    GnomeVFSFileSize *bytes_read,
 		    GnomeVFSCancellation *cancellation)
 {
-#if HAVE_OPENSSL
+#ifdef HAVE_OPENSSL
 	int ret, error;
 	GnomeVFSResult res;
 	
@@ -490,7 +490,7 @@ gnome_vfs_ssl_write (GnomeVFSSSL *ssl,
 		     GnomeVFSFileSize *bytes_written,
 		     GnomeVFSCancellation *cancellation)
 {
-#if HAVE_OPENSSL
+#ifdef HAVE_OPENSSL
 	int ret, error;
 	GnomeVFSResult res;
 	
@@ -553,7 +553,7 @@ void
 gnome_vfs_ssl_destroy (GnomeVFSSSL *ssl,
 		       GnomeVFSCancellation *cancellation) 
 {
-#if HAVE_OPENSSL
+#ifdef HAVE_OPENSSL
 	int ret, error;
 	GnomeVFSResult res;
 
@@ -613,7 +613,7 @@ gnome_vfs_ssl_set_timeout (GnomeVFSSSL *ssl,
 			   GTimeVal *timeout,
 			   GnomeVFSCancellation *cancellation)
 {
-#if HAVE_OPENSSL
+#ifdef HAVE_OPENSSL
 	/* reset a timeout */
 	if (timeout == NULL) {
 		if (ssl->private->timeout != NULL) {
